@@ -10,9 +10,9 @@ Get software version information
 
 def release() -> str:
     """Returns the software version number"""
-    return "0.5.1"
+    return "0.6.0"
 
 
 def date() -> str:
     """Returns the creation date of this release"""
-    return "24 January 2021"
+    return "05 March 2021"
